==> ejc-zdsmaterialb-api-3.0.0-20241014.032806-28-sources.jar: com/ejianc/business/zdsmaterial/material/vo/OrderQueryVo.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

public class OrderQueryVo {
    private String billCode; //单据编号
    private String contractName;//合同名称
    private String supplierName;//供应商名称
    private BigDecimal detailNum;//数量
    private BigDecimal acceptedNum;//验收数量
    private BigDecimal deliveredNum;//未发货数量
    private BigDecimal deliverNum;//发货数量
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialTypeCode; // 物资类别名称
    private Long materialId;
    private Long  orderId;
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date signTime;//时间

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }

    public BigDecimal getAcceptedNum() {
        return acceptedNum;
    }

    public void setAcceptedNum(BigDecimal acceptedNum) {
        this.acceptedNum = acceptedNum;
    }

    public BigDecimal getDeliveredNum() {
        return deliveredNum;
    }

    public void setDeliveredNum(BigDecimal deliveredNum) {
        this.deliveredNum = deliveredNum;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    public Date getSignTime() {
        return signTime;
    }

    public void setSignTime(Date signTime) {
        this.signTime = signTime;
    }

    public BigDecimal getDeliverNum() {
        return deliverNum;
    }

    public void setDeliverNum(BigDecimal deliverNum) {
        this.deliverNum = deliverNum;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
}

==> ejc-zdsmaterialb-api-3.0.0-20251206.092311-104-sources.jar: com/ejianc/business/zdsmaterial/material/vo/OrderQueryVo.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

public class OrderQueryVo {
    private String billCode; //单据编号
    private String contractName;//合同名称
    private String supplierName;//供应商名称
    private BigDecimal detailNum;//数量
    private BigDecimal acceptedNum;//验收数量
    private BigDecimal deliveredNum;//未发货数量
    private BigDecimal deliverNum;//发货数量
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialTypeCode; // 物资类别名称
    private Long materialId; //物料id
    private String materialCode;//物料编码
    private String materialName; //物料名称
    private String materialSpec; //规格属性
    private Long materialUnitId; //单位ID
    private String materialUnitName; //单位
    private Long  orderId;
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date signTime;//时间

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }

    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }

    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }

    public BigDecimal getAcceptedNum() {
        return acceptedNum;
    }

    public void setAcceptedNum(BigDecimal acceptedNum) {
        this.acceptedNum = acceptedNum;
    }

    public BigDecimal getDeliveredNum() {
        return deliveredNum;
    }

    public void setDeliveredNum(BigDecimal deliveredNum) {
        this.deliveredNum = deliveredNum;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    public Date getSignTime() {
        return signTime;
    }

    public void setSignTime(Date signTime) {
        this.signTime = signTime;
    }

    public BigDecimal getDeliverNum() {
        return deliverNum;
    }

    public void setDeliverNum(BigDecimal deliverNum) {
        this.deliverNum = deliverNum;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
}
